low constant
ImageCompression
const low
Low image compression, with higher quality and larger file size.
Implementation
static const low = ImageCompression._(30);
Low image compression, with higher quality and larger file size.
static const low = ImageCompression._(30);