none constant
ImageCompression
const none
No compression, with highest quality and largest file size.
Implementation
static const none = ImageCompression._(0);
No compression, with highest quality and largest file size.
static const none = ImageCompression._(0);