ImageFromPdfConfig class

Configuration for generating images from a PDF.

Constructors

ImageFromPdfConfig({ImageScale? rescale, ImageCompression compression = ImageCompression.none, bool createOneImage = false})
Creates an instance of ImageFromPdfConfig.
const

Properties

compression → ImageCompression
The image compression level for compression, affecting file size, quality and clarity.
final
createOneImage → bool
Indicates whether to create a single image or separate images for each page.
final
hashCode → int
The hash code for this object.
no setterinherited
rescale → ImageScale
The scale to apply to the images when generating the PDF.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited