BytesMergeInput class

A MergeInput representing a byte array.

Inheritance

Constructors

BytesMergeInput(Uint8List bytes)
const

Properties

bytes Uint8List
The byte array, if this input is created from bytes.
final
hashCode int
The hash code for this object.
no setterinherited
path String?
The file path, if this input is created from a path.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MergeInputType
Gets the type of input.
no setteroverride
url String?
The URL, if this input is created from a URL.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited