bytes property
Uint8List?
get
bytes
The byte array, if this input is created from bytes.
Implementation
Uint8List? get bytes => null;
The byte array, if this input is created from bytes.
Uint8List? get bytes => null;