path property
String?
get
path
The file path, if this input is created from a path.
Implementation
String? get path => null;
The file path, if this input is created from a path.
String? get path => null;