UrlMergeInput class
A MergeInput representing a URL.
- Inheritance
-
- Object
- MergeInput
- UrlMergeInput
Constructors
- UrlMergeInput(String url)
-
const
Properties
- bytes → Uint8List?
-
The byte array, if this input is created from bytes.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String?
-
The file path, if this input is created from a path.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → MergeInputType
-
Gets the type of input.
no setteroverride
- url → String
-
The URL, if this input is created from a URL.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited