PdfFromMultipleImageConfig class

Configuration for generating a PDF from multiple images.

Constructors

PdfFromMultipleImageConfig({ImageScale rescale = ImageScale.original, bool keepAspectRatio = true})
Creates an instance of PdfFromMultipleImageConfig.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keepAspectRatio → bool
Indicates whether to maintain the aspect ratio of the images.
final
rescale → ImageScale
The scale to apply to the images when generating the PDF.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this PdfFromMultipleImageConfig instance to a Map<String, dynamic>.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited