onError property
Callback triggered when an error occurs during the PDF combination process.
The error parameter provides details about the encountered exception.
Implementation
Function(Exception)? onError;
Callback triggered when an error occurs during the PDF combination process.
The error parameter provides details about the encountered exception.
Function(Exception)? onError;