registerWith static method

void registerWith(
  1. Registrar registrar
)

Registers the PdfCombinerWeb instance as the platform implementation. This method is called by the Flutter framework to link the platform interface with the web implementation.

Implementation

static void registerWith(Registrar registrar) {
  _ensureScriptsLoaded().catchError((Object _) {
    // Ignore failures during initial load to prevent crashes on startup,
    // but they will trigger during function invocations.
  });
  PdfCombinerPlatform.instance = PdfCombinerWeb();
}