MergeInput class sealed
A class representing an input for merging PDFs.
It can be created from a file path, a byte array, or a URL.
- Implementers
Constructors
- MergeInput.bytes(Uint8List bytes)
-
Creates a MergeInput from a byte array.
factory
- MergeInput.path(String path)
-
Creates a MergeInput from a file path.
factory
- MergeInput.url(String url)
-
Creates a MergeInput from a URL.
factory
Properties
- bytes → Uint8List?
-
The byte array, if this input is created from bytes.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String?
-
The file path, if this input is created from a path.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → MergeInputType
-
Gets the type of input.
no setter
- url → String?
-
The URL, if this input is created from a URL.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited